@@ -4,13 +4,13 @@
 clip() {
 	local sleep_argv0="password store sleep for user $(id -u)"
 	pkill -f "^$sleep_argv0" 2>/dev/null && sleep 0.5
-	local before="$(pbpaste | openssl base64)"
+	local before="$(pbpaste | $BASE64)"
 	echo -n "$1" | pbcopy
 	(
 		( exec -a "$sleep_argv0" sleep "$CLIP_TIME" )
-		local now="$(pbpaste | openssl base64)"
-		[[ $now != $(echo -n "$1" | openssl base64) ]] && before="$now"
-		echo "$before" | openssl base64 -d | pbcopy
+		local now="$(pbpaste | $BASE64)"
+		[[ $now != $(echo -n "$1" | $BASE64) ]] && before="$now"
+		echo "$before" | $BASE64 -d | pbcopy
 	) >/dev/null 2>&1 & disown
 	echo "Copied $2 to clipboard. Will clear in $CLIP_TIME seconds."
 }
@@ -45,3 +45,4 @@ qrcode() {
 
 GETOPT="$(brew --prefix gnu-getopt 2>/dev/null || { which port &>/dev/null && echo /opt/local; } || echo /usr/local)/bin/getopt"
 SHRED="srm -f -z"
+BASE64="openssl base64"
